InspectionResult class

Constructors

InspectionResult({required Uri uri, required String method, required int statusCode, required Map<String, String> headers, required String body, bool isJson = false})
const

Properties

body String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
isJson bool
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString({int? maxBodyChars}) String
toMap({int? maxBodyChars}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited